@@ -65,7 +65,7 @@ void NAME(struct model *M, const seq_t *sequences, size_t n) {
 
 			size_t ql = sequences[j].len;
 
-			M(i, j) = dist_anchor(&E, sequences[j].S, ql, subject.gc);
+			M(i, j) = dist_anchor(&E, sequences[j].S, ql, subject.threshold);
 
 #pragma omp atomic update
 			progress_counter++;
