@@ -91,8 +91,8 @@ int esa_init_cache(esa_s *self) {
  *
  * This function is a depth first search on the virtual suffix tree and fills
  * the cache. Or rather it calls it self until some value to cache is
- * calculated. This function is a recursive version of get_inteval but with more
- * edge cases.
+ * calculated. This function is a recursive version of get_interval but with
+ * more edge cases.
  *
  * @param C - The ESA.
  * @param str - The current prefix.
@@ -121,6 +121,15 @@ void esa_init_cache_dfs(esa_s *C, char *str, size_t pos, const lcp_inter_t in) {
 
 		// fail early
 		if (ij.i == -1 && ij.j == -1) {
+			// if the current extension cannot be found, will with previous one
+			esa_init_cache_fill(C, str, pos + 1, in);
+			continue;
+		}
+
+		// singleton
+		if (ij.i == ij.j) {
+			// fix length
+			ij.l = pos + 1;
 			esa_init_cache_fill(C, str, pos + 1, ij);
 			continue;
 		}
@@ -166,6 +175,10 @@ void esa_init_cache_dfs(esa_s *C, char *str, size_t pos, const lcp_inter_t in) {
 			str[k] = c;
 		}
 
+		// We are skipping intervals here. Maybe for each of them we should also
+		// fill the cache. However, I haven't yet figured out how to do that
+		// properly and whether it is worth it.
+
 		if (non_acgt) {
 			esa_init_cache_fill(C, str, k, ij);
 		} else {
@@ -287,15 +300,7 @@ int esa_init_SA(esa_s *C) {
 	C->SA = malloc(C->len * sizeof(*C->SA));
 	CHECK_MALLOC(C->SA);
 
-	saidx_t result = 1;
-
-#ifdef HAVE_LIBDIVSUFSORT
-	result = divsufsort((const unsigned char *)C->S, C->SA, C->len);
-#else
-	result = c_psufsort(C->S, C->SA);
-#endif
-
-	return result;
+	return divsufsort((const unsigned char *)C->S, C->SA, C->len);
 }
 
 /** @brief Initializes the CLD (child) array.
@@ -322,7 +327,7 @@ int esa_init_CLD(esa_s *C) {
 	pair_t *top = stack; // points at the topmost filled element
 	pair_t last;
 
-	R(CLD, 0) = C->len + 1;
+	R(CLD, 0) = C->len;
 
 	top->idx = 0;
 	top->lcp = -1;
@@ -462,9 +467,17 @@ static lcp_inter_t get_interval(const esa_s *self, lcp_inter_t ij, char a) {
 	SoSueMe:
 		if (c == a) {
 			/* found ! */
-			saidx_t n = L(CLD, m);
 
-			ij = (lcp_inter_t){.i = i, .j = m - 1, .m = n, .l = LCP[n]};
+			if (i != m - 1) {
+				// found interval contains >1 element
+				saidx_t n = L(CLD, m);
+
+				ij = (lcp_inter_t){.i = i, .j = m - 1, .m = n, .l = LCP[n]};
+			} else {
+				// empty or singleton
+				// doing L(CLD, m) is not valid in this case!
+				ij = (lcp_inter_t){.i = i, .j = i, .m = -1, .l = LCP[i]};
+			}
 
 			return ij;
 		}
