@@ -96,7 +96,7 @@ size_t string_vector_size(const struct string_vector *sv) {
 }
 
 /**
- * @brief Read a *fof* and add it's contents into a vector.
+ * @brief Read a *fof* and add its contents into a vector.
  * @param file_name - The file of file names aka. fof.
  * @param sv - The vector to add file names to.
  */
@@ -204,35 +204,32 @@ void read_fasta(const char *file_name, dsa_t *dsa) {
 		return;
 	}
 
-	int l;
-	int check;
-
-	seq_t top = {};
-	pfasta_file pf;
-
-	if ((l = pfasta_parse(&pf, file_descriptor)) != 0) {
-		soft_errx("%s: %s", file_name, pfasta_strerror(&pf));
+	struct pfasta_parser pp = pfasta_init(file_descriptor);
+	if (pp.errstr) {
+		soft_errx("%s: %s", file_name, pp.errstr);
 		goto fail;
 	}
 
-	pfasta_seq ps;
-	while ((l = pfasta_read(&pf, &ps)) == 0) {
-		check = seq_init(&top, ps.seq, ps.name);
+	seq_t top = {};
+	while (!pp.done) {
+		struct pfasta_record pr = pfasta_read(&pp);
+		if (pp.errstr) {
+			soft_errx("%s: %s", file_name, pp.errstr);
+			goto fail;
+		}
+
+		int check = seq_init(&top, pr.sequence, pr.name);
 
 		// skip broken sequences
 		if (check != 0) continue;
 
 		dsa_push(dsa, top);
-		pfasta_seq_free(&ps);
+		pfasta_record_free(&pr);
 	}
 
-	if (l < 0) {
-		soft_errx("%s: %s", file_name, pfasta_strerror(&pf));
-		pfasta_seq_free(&ps);
-	}
 
 fail:
-	pfasta_free(&pf);
+	pfasta_free(&pp);
 	close(file_descriptor);
 }
 
@@ -295,10 +292,10 @@ void print_distances(const struct model *D, const seq_t *sequences, size_t n,
 				double coverage1 = model_coverage(&D(i, j));
 				double coverage2 = model_coverage(&D(j, i));
 
-				if (coverage1 < 0.05 || coverage2 < 0.05) {
+				if (coverage1 < 0.2 || coverage2 < 0.2) {
 					const char str[] = {
-						"For the two sequences '%s' and '%s' less than 5%% "
-						"homology were found (%f and %f, respectively)."};
+						"For the two sequences '%s' and '%s' very little "
+						"homology was found (%f and %f, respectively)."};
 					soft_errx(str, sequences[i].name, sequences[j].name,
 							  coverage1, coverage2);
 				}
