@@ -6,6 +6,7 @@
 
 int FLAGS = F_NONE;
 int THREADS = 1;
+double ANCHOR_P_VALUE = 0.025;
 
 extern const int CACHE_LENGTH;
 
@@ -98,6 +99,7 @@ void teardown( esa_fixture *ef, gconstpointer test_data){
 	free(ef->C);
 	seq_free(ef->S);
 	free(ef->S);
+	seq_subject_free(&ef->subject);
 }
 
 extern int count;
@@ -162,6 +164,9 @@ void normq_cached( esa_fixture *ef, gconstpointer test_data){
 	b = get_match(C, "AAAAAAAAAAAA", 12);
 	assert_equal_lcp( &a, &b);
 
+	a = get_match_cached(C, "!AAAAAAAAAAAA", 12);
+	b = get_match(C, "!AAAAAAAAAAAA", 12);
+	assert_equal_lcp( &a, &b);
 }
 
 size_t MAX_DEPTH = 11;
